---
slug: /roles-overview
---

# Overview of role management

seekdb supports role management.

A role is a combination of permissions. By using roles, you can easily manage user permissions.

In seekdb, roles have the following features:

* Like regular users, roles can be granted permissions.

* Roles can be granted to other roles, meaning a role can contain other roles.

* A user can be granted multiple roles, and a role can be granted to multiple users.

Currently, seekdb does not support default system roles.

## References

For more information about role management, see:

* [Create a role](200.create-a-role.md)

* [Grant privileges to a role](300.grant-privileges-to-a-role.md)

* [Grant a role to a user or role](400.grant-a-role-to-a-role-or-user.md)

* [Activate roles](500.activate-roles.md)

* [View roles](600.view-roles.md)

* [Revoke privileges from a role](700.revoke-privileges-from-a-role.md)

* [Revoke a role from a user or role](800.revoke-a-role-from-a-user-or-role.md)

* [Delete a role](900.delete-a-role.md)